import Link from "next/link";
import { ArrowRight, CheckCircle2 } from "lucide-react";

import { Button } from "@/components/ui/button";
import {
  Card,
  CardContent,
  CardDescription,
  CardHeader,
  CardTitle,
} from "@/components/ui/card";
import { Container } from "@/components/ui/container";
import { Section } from "@/components/ui/section";
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs";
import {
  TypographyH1,
  TypographyH2,
  TypographyLead,
  TypographyMuted,
} from "@/components/ui/typography";
import { NavBar } from "@/components/layout/nav-bar";

export default function HomePage() {
  return (
    <div className="flex min-h-screen flex-col">
      <NavBar />
      <main className="flex-1">
        <Section className="pb-0">
          <Container>
            <div className="flex flex-col items-center justify-center space-y-8 text-center">
              <TypographyH1 className="text-4xl font-bold tracking-tighter sm:text-5xl md:text-6xl lg:text-7xl">
                Q58 Connect
              </TypographyH1>
              <TypographyLead className="max-w-[600px]">
                使用 Q58 论坛账号，一键登录您的应用
              </TypographyLead>
              <div className="flex gap-4">
                <Link href="/sign-in">
                  <Button size="lg">
                    开始使用
                    <ArrowRight className="ml-2 h-5 w-5" />
                  </Button>
                </Link>
              </div>
            </div>
          </Container>
        </Section>

        <Section>
          <Container>
            <div className="grid gap-8 md:grid-cols-3">
              <Card>
                <CardHeader>
                  <CardTitle>简单集成</CardTitle>
                  <CardDescription>
                    只需几行代码，即可为您的应用添加 Q58 论坛账号登录功能
                  </CardDescription>
                </CardHeader>
                <CardContent>
                  <ul className="space-y-2">
                    <li className="flex items-center gap-2">
                      <CheckCircle2 className="h-5 w-5 text-green-500" />
                      <span>标准 OAuth 2.0 协议</span>
                    </li>
                    <li className="flex items-center gap-2">
                      <CheckCircle2 className="h-5 w-5 text-green-500" />
                      <span>完整的开发文档</span>
                    </li>
                    <li className="flex items-center gap-2">
                      <CheckCircle2 className="h-5 w-5 text-green-500" />
                      <span>示例代码和SDK</span>
                    </li>
                  </ul>
                </CardContent>
              </Card>

              <Card>
                <CardHeader>
                  <CardTitle>安全可靠</CardTitle>
                  <CardDescription>
                    采用业界最佳实践，确保您的应用和用户数据安全
                  </CardDescription>
                </CardHeader>
                <CardContent>
                  <ul className="space-y-2">
                    <li className="flex items-center gap-2">
                      <CheckCircle2 className="h-5 w-5 text-green-500" />
                      <span>HTTPS 加密传输</span>
                    </li>
                    <li className="flex items-center gap-2">
                      <CheckCircle2 className="h-5 w-5 text-green-500" />
                      <span>授权码+令牌双重验证</span>
                    </li>
                    <li className="flex items-center gap-2">
                      <CheckCircle2 className="h-5 w-5 text-green-500" />
                      <span>防CSRF攻击</span>
                    </li>
                  </ul>
                </CardContent>
              </Card>

              <Card>
                <CardHeader>
                  <CardTitle>功能丰富</CardTitle>
                  <CardDescription>
                    提供完整的用户信息和权限管理功能
                  </CardDescription>
                </CardHeader>
                <CardContent>
                  <ul className="space-y-2">
                    <li className="flex items-center gap-2">
                      <CheckCircle2 className="h-5 w-5 text-green-500" />
                      <span>用户基本信息</span>
                    </li>
                    <li className="flex items-center gap-2">
                      <CheckCircle2 className="h-5 w-5 text-green-500" />
                      <span>用户组权限</span>
                    </li>
                    <li className="flex items-center gap-2">
                      <CheckCircle2 className="h-5 w-5 text-green-500" />
                      <span>管理员特权</span>
                    </li>
                  </ul>
                </CardContent>
              </Card>
            </div>
          </Container>
        </Section>

        <Section>
          <Container>
            <Card>
              <CardHeader>
                <CardTitle>快速开始</CardTitle>
                <CardDescription>
                  按照以下步骤，快速接入 Q58 Connect
                </CardDescription>
              </CardHeader>
              <CardContent>
                <Tabs defaultValue="auth" className="w-full">
                  <TabsList className="grid w-full grid-cols-3">
                    <TabsTrigger value="auth">发起授权</TabsTrigger>
                    <TabsTrigger value="callback">处理回调</TabsTrigger>
                    <TabsTrigger value="userinfo">获取用户</TabsTrigger>
                  </TabsList>
                  <TabsContent value="auth" className="mt-4">
                    <Card>
                      <CardHeader>
                        <CardTitle>1. 发起授权请求</CardTitle>
                        <CardDescription>
                          将用户重定向到授权页面
                        </CardDescription>
                      </CardHeader>
                      <CardContent>
                        <pre className="overflow-x-auto rounded-lg bg-gray-100 p-4 dark:bg-gray-800">
                          <code className="text-sm">
                            {`const authUrl = 'https://connect.q58.club/oauth/authorize?' + 
  new URLSearchParams({
    response_type: 'code',        // 必填，固定值
    client_id: 'your_client_id',  // 必填，您的应用ID
    redirect_uri: 'https://your-app.com/callback',
    state: 'random_state',        // 建议提供，防CSRF攻击
    scope: 'read_profile'         // 可选，默认read_profile
  });

window.location.href = authUrl;`}
                          </code>
                        </pre>
                      </CardContent>
                    </Card>
                  </TabsContent>
                  <TabsContent value="callback" className="mt-4">
                    <Card>
                      <CardHeader>
                        <CardTitle>2. 处理授权回调</CardTitle>
                        <CardDescription>
                          在回调地址处理授权结果
                        </CardDescription>
                      </CardHeader>
                      <CardContent>
                        <pre className="overflow-x-auto rounded-lg bg-gray-100 p-4 dark:bg-gray-800">
                          <code className="text-sm">
                            {`// 获取访问令牌
const response = await fetch('https://connect.q58.club/api/oauth/access_token', {
  method: 'POST',
  headers: {
    'Content-Type': 'application/x-www-form-urlencoded'
  },
  body: new URLSearchParams({
    code: '授权码',  // 回调参数中的code
    redirect_uri: 'https://your-app.com/callback'
  })
});

const { access_token, expires_in } = await response.json();`}
                          </code>
                        </pre>
                      </CardContent>
                    </Card>
                  </TabsContent>
                  <TabsContent value="userinfo" className="mt-4">
                    <Card>
                      <CardHeader>
                        <CardTitle>3. 获取用户信息</CardTitle>
                        <CardDescription>
                          使用访问令牌获取用户数据
                        </CardDescription>
                      </CardHeader>
                      <CardContent>
                        <pre className="overflow-x-auto rounded-lg bg-gray-100 p-4 dark:bg-gray-800">
                          <code className="text-sm">
                            {`const userInfo = await fetch('https://connect.q58.club/api/oauth/user', {
  headers: {
    'Authorization': \`Bearer \${access_token}\`
  }
}).then(res => res.json());

// 返回数据示例:
{
  "id": "user_xxx",
  "email": "user@example.com",
  "username": "username",
  "name": "用户昵称",
  "avatar_url": "https://...",
  "groups": ["group1", "group2"]
}`}
                          </code>
                        </pre>
                      </CardContent>
                    </Card>
                  </TabsContent>
                </Tabs>
              </CardContent>
            </Card>
          </Container>
        </Section>

        <Section>
          <Container>
            <div className="text-center">
              <TypographyH2>准备好了吗？</TypographyH2>
              <TypographyMuted className="mt-2">
                创建一个应用，开始使用 Q58 Connect
              </TypographyMuted>
              <div className="mt-4">
                <Link href="/sign-in">
                  <Button size="lg">立即开始</Button>
                </Link>
              </div>
            </div>
          </Container>
        </Section>
      </main>

      <footer className="border-t bg-white py-8 dark:bg-gray-800">
        <Container>
          <div className="text-center text-gray-600 dark:text-gray-400">
            © 2024{" "}
            <a
              href="https://q58.club"
              className="text-[#25263A] hover:underline dark:text-[#A0A1B2]"
            >
              Q58论坛
            </a>
            . 保留所有权利。
          </div>
        </Container>
      </footer>
    </div>
  );
}
