"use client";

import { useCallback, useEffect, useState } from "react";
import { signIn } from "@/actions/user-authorize";

import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card";

interface UserAuthorizeProps extends React.HTMLAttributes<HTMLDivElement> {
  data: Record<string, any>;
}

export function UserAuthorize({
  className,
  data,
  ...props
}: UserAuthorizeProps) {
  const [isLoading, setIsLoading] = useState<boolean>(false);
  const [error, setError] = useState<Error | unknown>(null);

  const signInCallback = useCallback(async () => {
    if (isLoading) {
      return;
    }
    setIsLoading(true);
    try {
      await signIn(data);
      setIsLoading(false);
    } catch (error) {
      console.error("登录过程出错:", error);
      setError(error);
      setIsLoading(false);
    }
  }, [data, isLoading]);

  useEffect(() => {
    const timer = setTimeout(signInCallback, 5);
    return () => {
      clearTimeout(timer);
    };
  }, [signInCallback]);

  if (error) {
    return (
      <Card className="w-full">
        <CardHeader className="space-y-4 text-center">
          <div className="mx-auto flex h-16 w-16 items-center justify-center rounded-full bg-red-100">
            <div className="h-8 w-8 text-red-600">❌</div>
          </div>
          <CardTitle className="text-2xl font-semibold text-red-600">
            授权失败
          </CardTitle>
        </CardHeader>
        <CardContent>
          <p className="text-center text-gray-500">
            {error instanceof Error
              ? error.message
              : "登录异常，授权失败！请稍后重试。"}
          </p>
        </CardContent>
      </Card>
    );
  }

  return (
    <Card className="w-full">
      <CardHeader className="space-y-4 text-center">
        <div className="mx-auto flex h-16 w-16 items-center justify-center rounded-full bg-blue-100">
          <div className="h-8 w-8 animate-spin rounded-full border-4 border-blue-600 border-t-transparent"></div>
        </div>
        <CardTitle className="text-2xl font-semibold">正在处理授权</CardTitle>
      </CardHeader>
      <CardContent>
        <p className="text-center text-gray-500">
          {isLoading ? "请稍候，我们正在处理您的授权请求" : "正在跳转..."}
        </p>
      </CardContent>
    </Card>
  );
}
