import "server-only";

import WordArray from "crypto-js/lib-typedarrays";

import { getClientByClientId } from "@/lib/dto/client";
import { createCode } from "@/lib/dto/code";

function generateAuthCode(): string {
  // 生成一个 48 字节的随机字符串
  const randomBytes = WordArray.random(48);
  // 转换为 base64 并移除可能的特殊字符
  return randomBytes
    .toString()
    .replace(/\+/g, "-")
    .replace(/\//g, "_")
    .replace(/=/g, "");
}

export async function getAuthorizeUrl(params: URLSearchParams) {
  // client
  const client = await getClientByClientId(params.get("client_id") as string);
  if (!client) {
    throw new Error("Client Id invalid (code: -1004).");
  }

  // redirect url
  const redirect_uri = new URL(client.redirectUri);
  if (params.has("state")) {
    redirect_uri.searchParams.append("state", params.get("state") || "");
  }
  const code = generateAuthCode();
  redirect_uri.searchParams.append("code", code);

  // storage code with shorter expiration time
  try {
    await createCode({
      code,
      expiresAt: new Date(Date.now() + 5 * 60 * 1000), // 5分钟过期
      clientId: client.id,
      userId: client.userId,
    });
  } catch {
    throw new Error("Create code error (code: -1005).");
  }

  return redirect_uri.toString();
}
